@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 13:51:10
-@LastEditTime: 2022-02-24 16:38:44
+@LastEditTime: 2022-05-06 09:51:45
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -51,6 +51,30 @@ class AddWechatSubscribeHandler(ClientBaseHandler):
         return self.response_json_success(invoke_result_data.data)
 
 
+class CreateWeChatQrCodeHandler(ClientBaseHandler):
+    """
+    :description: 创建微信小程序码
+    """
+    def get_async(self):
+        """
+        :description: 创建微信小程序码
+        :param page：跳转地址
+        :param scene：参数
+        :param width：宽度
+        :return: 二进制流
+        :last_editors: HuangJianYi
+        """
+        page = self.get_param("page", "pages/index/index")
+        scene = self.get_param("scene", "a=1")
+        width = self.get_param_int("width", 430)
+        invoke_result_data = WeChatHelper.create_qr_code(page, scene, width)
+        if invoke_result_data.success == True:
+            self.write(invoke_result_data.data)
+        else:
+            self.write("")
+        self.set_header("Content-type", "image/png")
+
+
 class GetHighPowerListHandler(ClientBaseHandler):
     """
     :description: 获取中台配置的高级权限列表
