@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-09-13 16:49:46
-@LastEditTime: 2022-01-22 11:46:41
+@LastEditTime: 2022-04-27 16:11:04
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -418,7 +418,6 @@ class ShakeshopNotifyHandler(FrameBaseHandler):
         sub_b_type_list = invoke_result_data.data["sub_b_type_list"] if invoke_result_data.data.__contains__("sub_b_type_list") else [] #下单场景，默认全部
         try:
             third_pay_order_model = ThirdPayOrderModel(context=self)
-            user_info_model = UserInfoModel(context=self)
             shop_id = config.get_value("shake_shop")["shop_id"]
             app_key = config.get_value("shake_shop")["app_key"]
             app_secret = config.get_value("shake_shop")["app_secret"]
@@ -438,77 +437,82 @@ class ShakeshopNotifyHandler(FrameBaseHandler):
                     order_detail_result = shakeshop_base_model.request(path="/order/orderDetail", params=params, is_log=False)
                     if order_detail_result and order_detail_result["code"] == 10000:
                         open_id = order_detail_result["data"]["shop_order_detail"]["open_id"]
-                        user_info_dict = user_info_model.get_cache_dict("open_id=%s", limit="1", order_by="id desc", params=[open_id])
-                        if user_info_dict:
-                            tiktok_goods_id_list = []
-                            if asset_type == 3:
-                                price_base_model = PriceBaseModel(context=self.context)
-                                price_gear_dict_list = price_base_model.get_price_gear_list(user_info_dict["app_id"], user_info_dict["act_id"], 100, 0).data
-                                for price_gear_dict in price_gear_dict_list:
-                                    tiktok_goods_id_list.append(price_gear_dict["goods_id"])
-                            else:
-                                tiktok_goods_id_list.append(str(goods_id))
-                            pay_order_no_list, redis_init, pay_order_cache_key = self.get_pay_order_no_list(user_info_dict["app_id"], user_info_dict["user_id"])
-                            third_pay_order_list = []
-                            total_buy_num = 0
-                            total_pay_price = 0
-                            for sku_order in order_detail_result["data"]["shop_order_detail"]["sku_order_list"]:
-                                asset_object_id = ""
-                                if len(sub_b_type_list) > 0 and sku_order["sub_b_type"] not in sub_b_type_list:
-                                    continue
-                                if str(sku_order["product_id"]) in tiktok_goods_id_list and sku_order["order_status"] in reward_order_status_list and sku_order["order_id"] not in pay_order_no_list:
-                                    if asset_type == 3:
-                                        now_price_gear_dict = None
-                                        for price_gear_dict in price_gear_dict_list:
-                                            if (price_gear_dict["effective_date"] == '1900-01-01 00:00:00' or TimeHelper.format_time_to_datetime(price_gear_dict["effective_date"]) < TimeHelper.format_time_to_datetime(TimeHelper.timestamp_to_format_time(sku_order["pay_time"]))) and price_gear_dict["goods_id"] == str(sku_order["product_id"]):
-                                                #关联类型：1商品skuid关联2商品id关联
-                                                if price_gear_dict["relation_type"] == 1 and price_gear_dict["sku_id"] != str(sku_order["sku_id"]):
-                                                    continue
-                                                now_price_gear_dict = price_gear_dict
-                                        if not now_price_gear_dict:
-                                            continue
-                                        asset_object_id = now_price_gear_dict["id"]
-                                    else:
-                                        if str(goods_id) != str(sku_order["product_id"]):
-                                            continue
-                                        if sku_id and str(sku_id) != str(sku_order["sku_id"]):
-                                            continue
-                                    third_pay_order = ThirdPayOrder()
-                                    third_pay_order.app_id = user_info_dict["app_id"]
-                                    third_pay_order.act_id = user_info_dict["act_id"]
-                                    third_pay_order.user_id = user_info_dict["user_id"]
-                                    third_pay_order.open_id = open_id
-                                    third_pay_order.user_nick = user_info_dict["user_nick"]
-                                    third_pay_order.goods_code = sku_order["product_id"]
-                                    third_pay_order.goods_name = sku_order["product_name"]
-                                    third_pay_order.order_status = sku_order["order_status"]
-                                    third_pay_order.sku_id = sku_order["sku_id"]
-                                    third_pay_order.sku_name = json.dumps(sku_order["spec"])
-                                    third_pay_order.buy_num = sku_order["item_num"]
-                                    third_pay_order.pay_price = decimal.Decimal(sku_order["pay_amount"] / 100)
-                                    third_pay_order.main_pay_order_no = sku_order["parent_order_id"]
-                                    third_pay_order.sub_pay_order_no = sku_order["order_id"]
-                                    third_pay_order.pay_date = TimeHelper.timestamp_to_format_time(sku_order["pay_time"])
-                                    third_pay_order.asset_type = asset_type
-                                    third_pay_order.asset_object_id = asset_object_id
-                                    third_pay_order.surplus_count = sku_order["item_num"]
-                                    third_pay_order.create_date = SevenHelper.get_now_datetime()
-                                    total_buy_num += int(sku_order["item_num"])
-                                    total_pay_price += decimal.Decimal(sku_order["pay_amount"] / 100)
-                                    third_pay_order_list.append(third_pay_order)
-                            if len(third_pay_order_list) > 0:
-                                third_pay_order_result = third_pay_order_model.add_list(third_pay_order_list)
-                                if third_pay_order_result == True and total_buy_num > 0:
-                                    #更新用户表
-                                    user_info_model.update_table("pay_price=pay_price+%s,pay_num=pay_num+%s", "user_id=%s", params=[total_pay_price, total_buy_num, user_info_dict["user_id"]])
-                                    asset_base_model = AssetBaseModel(context=self)
-                                    for item in third_pay_order_list:
-                                        only_id = str(item.sub_pay_order_no)
-                                        asset_invoke_result_data = asset_base_model.update_user_asset(user_info_dict["app_id"], user_info_dict["act_id"], 0, user_info_dict["user_id"], user_info_dict["open_id"], user_info_dict["user_nick"], item.asset_type, item.buy_num, item.asset_object_id, 1, "", "", "抖店购买", only_id, self.__class__.__name__, self.request_code, info_json={})
-                                        if asset_invoke_result_data.success == True:
-                                            redis_init.lpush(pay_order_cache_key, item.sub_pay_order_no)
-                                            redis_init.expire(pay_order_cache_key, 30 * 24 * 3600)
-                                    self.business_process_executed(third_pay_order_list, ref_params={"total_buy_num": total_buy_num, "total_pay_price": total_pay_price, "sku_order_list": order_detail_result["data"]["shop_order_detail"]["sku_order_list"]})
+                        act_info_model = ActInfoModel(context=self)
+                        act_info_dict = act_info_model.get_cache_dict(order_by="id desc")
+                        if act_info_dict:
+                            frame_base_model = FrameBaseModel(context=self)
+                            user_info_model = UserInfoModel(sub_table=frame_base_model.get_business_sub_table("user_info_tb", {"act_id": act_info_dict["id"], "user_id": 0}), context=self)
+                            user_info_dict = user_info_model.get_cache_dict("act_id=%s and open_id=%s", limit="1", order_by="id desc", params=[act_info_dict["id"],open_id])
+                            if user_info_dict:
+                                tiktok_goods_id_list = []
+                                if asset_type == 3:
+                                    price_base_model = PriceBaseModel(context=self.context)
+                                    price_gear_dict_list = price_base_model.get_price_gear_list(user_info_dict["app_id"], user_info_dict["act_id"], 100, 0).data
+                                    for price_gear_dict in price_gear_dict_list:
+                                        tiktok_goods_id_list.append(price_gear_dict["goods_id"])
+                                else:
+                                    tiktok_goods_id_list.append(str(goods_id))
+                                pay_order_no_list, redis_init, pay_order_cache_key = self.get_pay_order_no_list(user_info_dict["app_id"], user_info_dict["user_id"])
+                                third_pay_order_list = []
+                                total_buy_num = 0
+                                total_pay_price = 0
+                                for sku_order in order_detail_result["data"]["shop_order_detail"]["sku_order_list"]:
+                                    asset_object_id = ""
+                                    if len(sub_b_type_list) > 0 and sku_order["sub_b_type"] not in sub_b_type_list:
+                                        continue
+                                    if str(sku_order["product_id"]) in tiktok_goods_id_list and sku_order["order_status"] in reward_order_status_list and sku_order["order_id"] not in pay_order_no_list:
+                                        if asset_type == 3:
+                                            now_price_gear_dict = None
+                                            for price_gear_dict in price_gear_dict_list:
+                                                if (price_gear_dict["effective_date"] == '1900-01-01 00:00:00' or TimeHelper.format_time_to_datetime(price_gear_dict["effective_date"]) < TimeHelper.format_time_to_datetime(TimeHelper.timestamp_to_format_time(sku_order["pay_time"]))) and price_gear_dict["goods_id"] == str(sku_order["product_id"]):
+                                                    #关联类型：1商品skuid关联2商品id关联
+                                                    if price_gear_dict["relation_type"] == 1 and price_gear_dict["sku_id"] != str(sku_order["sku_id"]):
+                                                        continue
+                                                    now_price_gear_dict = price_gear_dict
+                                            if not now_price_gear_dict:
+                                                continue
+                                            asset_object_id = now_price_gear_dict["id"]
+                                        else:
+                                            if str(goods_id) != str(sku_order["product_id"]):
+                                                continue
+                                            if sku_id and str(sku_id) != str(sku_order["sku_id"]):
+                                                continue
+                                        third_pay_order = ThirdPayOrder()
+                                        third_pay_order.app_id = user_info_dict["app_id"]
+                                        third_pay_order.act_id = user_info_dict["act_id"]
+                                        third_pay_order.user_id = user_info_dict["user_id"]
+                                        third_pay_order.open_id = open_id
+                                        third_pay_order.user_nick = user_info_dict["user_nick"]
+                                        third_pay_order.goods_code = sku_order["product_id"]
+                                        third_pay_order.goods_name = sku_order["product_name"]
+                                        third_pay_order.order_status = sku_order["order_status"]
+                                        third_pay_order.sku_id = sku_order["sku_id"]
+                                        third_pay_order.sku_name = json.dumps(sku_order["spec"])
+                                        third_pay_order.buy_num = sku_order["item_num"]
+                                        third_pay_order.pay_price = decimal.Decimal(sku_order["pay_amount"] / 100)
+                                        third_pay_order.main_pay_order_no = sku_order["parent_order_id"]
+                                        third_pay_order.sub_pay_order_no = sku_order["order_id"]
+                                        third_pay_order.pay_date = TimeHelper.timestamp_to_format_time(sku_order["pay_time"])
+                                        third_pay_order.asset_type = asset_type
+                                        third_pay_order.asset_object_id = asset_object_id
+                                        third_pay_order.surplus_count = sku_order["item_num"]
+                                        third_pay_order.create_date = SevenHelper.get_now_datetime()
+                                        total_buy_num += int(sku_order["item_num"])
+                                        total_pay_price += decimal.Decimal(sku_order["pay_amount"] / 100)
+                                        third_pay_order_list.append(third_pay_order)
+                                if len(third_pay_order_list) > 0:
+                                    third_pay_order_result = third_pay_order_model.add_list(third_pay_order_list)
+                                    if third_pay_order_result == True and total_buy_num > 0:
+                                        #更新用户表
+                                        user_info_model.update_table("pay_price=pay_price+%s,pay_num=pay_num+%s", "user_id=%s", params=[total_pay_price, total_buy_num, user_info_dict["user_id"]])
+                                        asset_base_model = AssetBaseModel(context=self)
+                                        for item in third_pay_order_list:
+                                            only_id = str(item.sub_pay_order_no)
+                                            asset_invoke_result_data = asset_base_model.update_user_asset(user_info_dict["app_id"], user_info_dict["act_id"], 0, user_info_dict["user_id"], user_info_dict["open_id"], user_info_dict["user_nick"], item.asset_type, item.buy_num, item.asset_object_id, 1, "", "", "抖店购买", only_id, self.__class__.__name__, self.request_code, info_json={})
+                                            if asset_invoke_result_data.success == True:
+                                                redis_init.lpush(pay_order_cache_key, item.sub_pay_order_no)
+                                                redis_init.expire(pay_order_cache_key, 30 * 24 * 3600)
+                                        self.business_process_executed(third_pay_order_list, ref_params={"total_buy_num": total_buy_num, "total_pay_price": total_pay_price, "sku_order_list": order_detail_result["data"]["shop_order_detail"]["sku_order_list"]})
                     else:
                         self.logging_link_info("【抖店异步通知结果】" + str(result) + ":" + str(order_detail_result))
                 return self.write({'code': 0, 'msg': 'success'})
