@@ -298,7 +298,8 @@ class InviteNewUserHandler(ClientBaseHandler):
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
         check_new_user = invoke_result_data.data["check_new_user"] if invoke_result_data.data.__contains__("check_new_user") else True
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
-        invoke_result_data = task_base_model.process_invite_new_user(app_id, act_id, module_id, user_id, login_token, from_user_id, self.__class__.__name__, check_user_nick, check_new_user, continue_request_expire)
+        close_invite_limit = invoke_result_data.data["close_invite_limit"] if invoke_result_data.data.__contains__("close_invite_limit") else False
+        invoke_result_data = task_base_model.process_invite_new_user(app_id, act_id, module_id, user_id, login_token, from_user_id, self.__class__.__name__, check_user_nick, check_new_user, continue_request_expire, close_invite_limit)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
@@ -340,11 +341,12 @@ class InviteJoinMemberHandler(ClientBaseHandler):
             invoke_result_data.data = {}
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
+        close_invite_limit = invoke_result_data.data["close_invite_limit"] if invoke_result_data.data.__contains__("close_invite_limit") else False
         app_key, app_secret = self.get_app_key_secret()
         app_base_model = AppBaseModel(context=self)
         app_info_dict = app_base_model.get_app_info_dict(app_id)
         access_token = app_info_dict["access_token"] if app_info_dict else ""
-        invoke_result_data = task_base_model.process_invite_join_member(app_id, act_id, module_id, user_id, login_token, from_user_id, self.__class__.__name__, access_token, app_key, app_secret, check_user_nick, continue_request_expire)
+        invoke_result_data = task_base_model.process_invite_join_member(app_id, act_id, module_id, user_id, login_token, from_user_id, self.__class__.__name__, access_token, app_key, app_secret, check_user_nick, continue_request_expire, close_invite_limit)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
@@ -478,7 +480,7 @@ class FavorStoreHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        return self.response_json_success(invoke_result_data.data)
+        return self.response_json_success(invoke_result_data.data["reward_value"])
 
 
 class JoinMemberHandler(ClientBaseHandler):
@@ -524,7 +526,7 @@ class JoinMemberHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        return self.response_json_success(invoke_result_data.data)
+        return self.response_json_success(invoke_result_data.data["reward_value"])
 
 
 class BrowseSiteHandler(ClientBaseHandler):
