@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 18:31:06
-@LastEditTime: 2022-03-08 17:38:37
+@LastEditTime: 2022-04-28 14:05:09
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -261,7 +261,8 @@ class GetCouponPrizeHandler(ClientBaseHandler):
         if access_token == "":
             return self.response_json_error("error", "未授权请联系客服授权")
         dependency_key = f"prize_roster_list:actid_{act_id}_userid_{user_id}"
-        prize_roster_model = PrizeRosterModel(context=self)
+        frame_base_model = FrameBaseModel(context=self)
+        prize_roster_model = PrizeRosterModel(sub_table=frame_base_model.get_business_sub_table("prize_roster_tb", {"act_id": act_id, "user_id": 0}), context=self)
         prize_roster_dict = prize_roster_model.get_cache_dict_by_id(user_prize_id, dependency_key=dependency_key)
         if not prize_roster_dict or prize_roster_dict['user_id'] != user_id or prize_roster_dict['act_id'] != act_id:
             return self.response_json_error("error", "奖品不存在")
