@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-15 11:30:45
-@LastEditTime: 2022-03-09 17:18:30
+@LastEditTime: 2022-04-27 10:11:41
 @LastEditors: HuangJianYi
 @Description: 公共handler模块
 """
@@ -28,6 +28,7 @@ from seven_cloudapp_frame.models.db_models.act.act_info_model import *
 from seven_cloudapp_frame.models.db_models.operation.operation_log_model import *
 from seven_cloudapp_frame.models.mp_base_model import MPBaseModel
 from seven_cloudapp_frame.models.app_base_model import AppBaseModel
+from seven_cloudapp_frame.handlers.filter_base import *
 
 
 class FrameBaseHandler(BaseApiHandler):
@@ -64,10 +65,10 @@ class FrameBaseHandler(BaseApiHandler):
             dict_param = self.get_http_log_extra_dict()
             self._build_http_log(dict_param)
             # 记录请求参数明文
-            if config.get_value("log_plain",True) == True and self.check_api_is_encrypt() == True:
+            if config.get_value("is_log_plain", True) == True and self.is_api_encrypt() == True:
                 self.logging_link_info(f"plain_request_params:{self.json_dumps(self.request_params)}")
-            
-            
+
+
         except Exception as ex:
             if not hasattr(self, "request_code"):
                 self.request_code = UUIDHelper.get_uuid()
@@ -139,7 +140,7 @@ class FrameBaseHandler(BaseApiHandler):
             param = default
         return param
 
-    def check_api_is_encrypt(self):
+    def is_api_encrypt(self):
         """
         :Description: 校验是否加密
         :last_editors: HuangJianYi
@@ -159,7 +160,7 @@ class FrameBaseHandler(BaseApiHandler):
         """
         invoke_result_data = InvokeResultData()
         self.request_params = {}
-        if self.check_api_is_encrypt() == True:
+        if self.is_api_encrypt() == True:
             encrypt_key = config.get_value("encrypt_key", "r8C1JpyAXxrFV26V")
             if hasattr(self, "encrypt_key"):
                 encrypt_key = self.encrypt_key
@@ -247,7 +248,7 @@ class FrameBaseHandler(BaseApiHandler):
         if is_encrypt == False:
             template_value['data'] = data
         else:
-            if self.check_api_is_encrypt() == True:
+            if self.is_api_encrypt() == True:
                 dv = SevenHelper.get_random(16)
                 encrypt_key = config.get_value("encrypt_key", "r8C1JpyAXxrFV26V")
                 if self.get_argument("app_id", "", strip=True):
@@ -275,7 +276,7 @@ class FrameBaseHandler(BaseApiHandler):
         log_extra_dict["is_success"] = 1
         if success == False:
             log_extra_dict["is_success"] = 0
-        
+
         self.http_reponse(self.json_dumps(rep_dic), log_extra_dict)
 
     def response_json_success(self, data=None):
@@ -498,11 +499,11 @@ class FrameBaseHandler(BaseApiHandler):
             if store_user_nick and store_user_nick == test_config.get("user_nick",""):
                 access_token = test_config.get("access_token","")
         return access_token
-        
+
     def create_operation_log(self, operation_type=1, model_name="", handler_name="", old_detail=None, update_detail=None, operate_user_id="", operate_user_name=""):
         """
         :description: 创建操作日志
-        :param operation_type：操作类型：1-add，2-update，3-delete
+        :param operation_type：操作类型：1-add，2-update，3-delete，4-review，5-copy
         :param model_name：模块或表名称
         :param handler_name：handler名称
         :param old_detail：当前信息
@@ -669,7 +670,7 @@ class ClientBaseHandler(FrameBaseHandler):
             self._build_http_log(dict_param)
 
             # 记录请求参数明文
-            if config.get_value("log_plain",True) == True and self.check_api_is_encrypt() == True:
+            if config.get_value("log_plain", True) == True and self.is_api_encrypt() == True:
                 self.logging_link_info(f"plain_request_params:{self.json_dumps(self.request_params)}")
 
             # 获取设备信息
@@ -683,10 +684,7 @@ class ClientBaseHandler(FrameBaseHandler):
                 return
 
             # 验证超时 10分钟过期
-            client_encrypt_type = config.get_value("client_encrypt_type", 0)
-            server_encrypt_type = config.get_value("server_encrypt_type", 0)
-            is_encrypt = False if hasattr(self, "is_encrypt") and self.is_encrypt == False else True
-            if is_encrypt == True and ("/server/" in self.request.uri and server_encrypt_type == 1) or ("/client/" in self.request.uri and client_encrypt_type == 1):
+            if self.is_api_encrypt() == True:
                 now_time = TimeHelper.get_now_timestamp(True)
                 if self.request_params.__contains__("timestamp") and (now_time - int(self.request_params["timestamp"]) > int(1000 * 60 * 10)):
                     self.response_json_error("timestamp", "超时操作")
@@ -703,7 +701,7 @@ class ClientBaseHandler(FrameBaseHandler):
 
                 #每分钟流量UV计数,用于登录接口限制登录
                 self.add_request_user(str(dict_param["app_id"]), str(dict_param["open_id"]))
-            
+
             # 校验是否有权限，有才能访问接口
             if not self.check_handler_power():
                 self.response_json_error("no_power", "没有权限操作")
@@ -785,199 +783,3 @@ class ClientBaseHandler(FrameBaseHandler):
         :last_editors: HuangJianYi 
         """
         return CryptographyHelper.emoji_to_emoji_base64(text_str)
-
-
-def filter_check_params(must_params=None):
-    """
-    :description: 参数过滤装饰器 仅限handler使用,
-                  提供参数的检查及获取参数功能
-                  装饰器使用方法:
-                  @client_filter_check_params("param_a,param_b,param_c")  或
-                  @client_filter_check_params(["param_a","param_b,param_c"])
-                  参数获取方法:
-                  self.request_params[param_key]
-    :param must_params: 必须传递的参数集合
-    :last_editors: HuangJianYi
-    """
-    def check_params(handler):
-        def wrapper(self, **args):
-            finally_must_params = must_params
-            if hasattr(self, "must_params"):
-                finally_must_params = self.must_params
-            if type(finally_must_params) == str:
-                must_array = finally_must_params.split(",")
-            if type(finally_must_params) == list:
-                must_array = finally_must_params
-
-            if finally_must_params:
-                for must_param in must_array:
-                    if not must_param in self.request_params or self.request_params[must_param] == "":
-                        self.response_json_error("param_error", "参数错误,缺少必传参数")
-                        return
-
-            return handler(self, **args)
-
-        return wrapper
-
-    return check_params
-
-
-def filter_check_request(check_params=None):
-    """
-    :description: 请求过滤装饰器 仅限handler使用,
-                    提供单用户是否存在对某一接口的达到指定请求数的持续请求的校验
-                    装饰器使用方法:
-                    @client_filter_check_params("param_a,param_b,param_c")  或
-                    @client_filter_check_params(["param_a","param_b,param_c"])
-    :param check_params: 校验参数集合
-    :last_editors: HuangJianYi
-    """
-    def check_request(handler):
-        def wrapper(self, **args):
-            object_id = self.get_open_id()
-            if not object_id:
-                object_id = self.get_user_id()
-
-            if self.request_params and object_id:
-
-                app_id = self.get_app_id()
-                if not app_id:
-                    app_id = self.get_source_app_id()
-
-                finally_check_params = []
-                if type(check_params) == str:
-                    finally_check_params = check_params.split(",")
-                if type(check_params) == list:
-                    finally_check_params = check_params
-                if finally_check_params:
-                    sign_params = {key: self.request_params[key] for key in self.request_params if key in finally_check_params}
-                else:
-                    sign_params = self.request_params
-                redis_init = SevenHelper.redis_init()
-                middle_key = f"{self.__class__.__name__}_{app_id}_{object_id}_{self.get_signature_md5(sign_params)}"
-                if redis_init.get(f"check_request_limit:{middle_key}"):
-                    self.response_json_error("request_error", "请求频繁,请稍后再试")
-                    return
-                cache_key = f"check_request_count:{middle_key}_{str(SevenHelper.get_now_int(fmt='%Y%m%d%H%M'))}"
-                cache_value = redis_init.get(cache_key)
-                if cache_value:
-                    cache_value = int(cache_value)
-                    if cache_value >= 30:
-                        redis_init.set(f"check_request_limit:{middle_key}", 1, 60)
-                        self.response_json_error("request_error", "请求频繁,请稍后再试")
-                        return
-                redis_init.incr(cache_key, 1)
-                redis_init.expire(cache_key, 120)
-
-            return handler(self, **args)
-
-        return wrapper
-
-    return check_request
-
-
-def filter_check_head_sign(is_check=True, no_check_params=None):
-    """
-    :description: 头部过滤装饰器 仅限handler使用
-    :param is_check: 是否开启校验
-    :param no_check_params: 不加入参数校验的参数集合
-    :last_editors: HuangJianYi
-    """
-    def check_head(handler):
-        def wrapper(self, **args):
-            encrypt_key = config.get_value("encrypt_key", "r8C1JpyAXxrFV26V")
-            is_check_head = config.get_value("is_check_head", False)
-            if is_check_head == False:
-                is_check = False
-            else:
-                is_check = True
-            if is_check == True:
-                try:
-                    if type(no_check_params) == str:
-                        no_check_array = no_check_params.split(",")
-                    elif type(no_check_params) == list:
-                        no_check_array = no_check_params
-                    else:
-                        no_check_array = []
-                    # 验证是否有设备信息
-                    clientheaderinfo_string = self.request.headers._dict.get("Clientheaderinfo")
-                    if clientheaderinfo_string:
-                        # 将设备信息字符串转为字典类型
-                        device_info_dict = self.device_info_dict(clientheaderinfo_string)
-                        # 验证签名超时 10分钟过期
-                        now_time = TimeHelper.get_now_timestamp(True)
-                        if now_time - device_info_dict["timestamp"] > int(1000 * 60 * 10):
-                            return self.response_json_error("timestamp", "超时操作")
-                        # 验证是否有头部信息签名
-                        if not device_info_dict.__contains__("signature_md5"):
-                            return self.response_json_error("signature_md5", "缺少参数signature_md5")
-                        # 验证头部签名是否成功
-                        client_head_dict = dict([(k, v[0]) for k, v in parse_qs(clientheaderinfo_string, True).items() if not k in no_check_array])
-                        head_signature_md5 = self.get_signature_md5(client_head_dict, encrypt_key)
-                        signature_md5 = device_info_dict["signature_md5"].lower()
-                        if signature_md5 != head_signature_md5:
-                            return self.response_json_error("signature_fail", "头部签名验证失败")
-                    else:
-                        return self.response_json_error("no_device_info", "没有提交设备信息")
-                except Exception as ex:
-                    self.logging_link_error("【头部校验异常】" + traceback.format_exc())
-                    return self.response_json_error("error", "头部验证失败")
-
-            return handler(self, **args)
-
-        return wrapper
-
-    return check_head
-
-
-def filter_check_params_sign(is_check=True, no_check_params=None):
-    """
-    :description: 请求参数过滤装饰器 仅限handler使用
-    :param is_check: 是否开启校验
-    :param no_check_params: 不加入参数校验的参数集合
-    :last_editors: HuangJianYi
-    """
-    def check_params(handler):
-        def wrapper(self, **args):
-            encrypt_key = config.get_value("encrypt_key", "r8C1JpyAXxrFV26V")
-            client_encrypt_type = config.get_value("client_encrypt_type", 0)
-            server_encrypt_type = config.get_value("server_encrypt_type", 0)
-            if ("/server/" in self.request.uri and server_encrypt_type != 2) or ("/client/" in self.request.uri and client_encrypt_type != 2):
-                is_check = False
-            else:
-                is_check = True
-            if is_check == True:
-                try:
-                    if type(no_check_params) == str:
-                        no_check_array = no_check_params.split(",")
-                    elif type(no_check_params) == list:
-                        no_check_array = no_check_params
-                    else:
-                        no_check_array = []
-                    # 验证参数
-                    request_param_dict = {}
-                    try:
-                        if self.request.method == "POST" and "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
-                            request_param_dict = json.loads(self.request.body)
-                        else:
-                            request_param_dict = dict([(k, v[0]) for k, v in parse_qs(self.request.query, True).items() if not k in no_check_array])
-                    except:
-                        pass
-                    if not request_param_dict.__contains__("param_signature_md5"):
-                        return self.response_json_error("signature_fail", "缺少参数param_signature_md5")
-                    check_request_signature_md5 = self.get_signature_md5(request_param_dict, encrypt_key)
-                    param_signature_md5 = request_param_dict["param_signature_md5"].lower()
-                    if check_request_signature_md5 != param_signature_md5:
-                        return self.response_json_error("signature_fail", "参数签名验证失败")
-
-                except Exception as ex:
-                    self.logging_link_error("【请求参数校验异常】" + traceback.format_exc())
-                    return self.response_json_error("error", "请求参数验证失败")
-
-            return handler(self, **args)
-
-        return wrapper
-
-    return check_params
-
-
