@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 10:43:58
-@LastEditTime: 2022-02-24 16:36:46
+@LastEditTime: 2022-03-11 11:10:29
 @LastEditors: HuangJianYi
 @Description: 应用模块
 """
@@ -29,19 +29,28 @@ class InstantiateAppHandler(ClientBaseHandler):
         """
         app_id = self.get_app_id()
         user_nick = self.get_user_nick()
-        access_token = self.get_param("access_token")
+        access_token = self.get_access_token()
         is_log = int(self.get_param("is_log", 0))
         is_log = True if is_log == 1 else False
 
         cache_key = f"instantiate:{user_nick}"
         if SevenHelper.is_continue_request(cache_key, 10000) == True:
             return self.response_json_error("error","操作太频繁,请10秒后再试")
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message,invoke_result_data.data)
         app_key, app_secret = self.get_app_key_secret()
         top_base_model = TopBaseModel(context=self)
         invoke_result_data = top_base_model.instantiate(app_id, user_nick, access_token, app_key, app_secret, is_log)
-        SevenHelper.redis_init().delete(cache_key)
         if invoke_result_data.success == False:
+            SevenHelper.redis_init().delete(cache_key)
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message,invoke_result_data.data)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
+        if invoke_result_data.success == False:
+            SevenHelper.redis_init().delete(cache_key)
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        SevenHelper.redis_init().delete(cache_key)
         return self.response_json_success(invoke_result_data.data)
 
 
@@ -87,7 +96,7 @@ class VersionUpgradeHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        access_token = self.get_param("access_token")
+        access_token = self.get_access_token()
         user_nick = self.get_user_nick()
         is_log = int(self.get_param("is_log", 0))
         is_log = True if is_log == 1 else False
@@ -106,11 +115,12 @@ class VersionUpgradeHandler(ClientBaseHandler):
         app_info = AppInfoModel(context=self).get_entity("app_id=%s", params=app_id)
         if not app_info:
             return self.response_json_error("no_app", "小程序不存在")
-
-        test_client_ver = config.get_value("test_client_ver")
+        test_config = config.get_value("test_config",{})
+        test_client_ver = test_config.get("client_ver","")
         client_template_id = config.get_value("client_template_id")
         #配置文件指定账号升级
-        if test_client_ver and user_nick == config.get_value("test_user_nick"):
+        store_user_nick = user_nick.split(':')[0]
+        if test_client_ver and store_user_nick and store_user_nick == test_config.get("user_nick",""):
             client_ver = test_client_ver
         top_base_model = TopBaseModel(context=self)
         app_key, app_secret = self.get_app_key_secret()
@@ -133,7 +143,7 @@ class AppInfoHandler(ClientBaseHandler):
         """
         app_base_model = AppBaseModel(context=self)
         app_key, app_secret = self.get_app_key_secret()
-        invoke_result_data = app_base_model.get_app_info_result(self.get_user_nick(), self.get_open_id(), self.get_param("access_token"), app_key, app_secret)
+        invoke_result_data = app_base_model.get_app_info_result(self.get_user_nick(), self.get_open_id(), self.get_access_token(), app_key, app_secret)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
@@ -141,27 +151,31 @@ class AppInfoHandler(ClientBaseHandler):
 
 class CheckGmPowerHandler(ClientBaseHandler):
     """
-    :description: 获取是否有GM工具权限
+    :description: 校验是否有GM工具权限
     """
     def get_async(self):
         """
-        :description: 获取是否有GM工具权限
+        :description: 校验是否有GM工具权限
         :param 
         :return: True是 False否
         :last_editors: HuangJianYi
         """
         is_power = False
-        store_user_nick = self.get_user_nick().split(':')[0]
-        if not store_user_nick:
-            return self.response_json_success(is_power)
-        if store_user_nick == config.get_value("test_user_nick"):
+        user_nick = self.get_user_nick()
+        if not user_nick:
+            return self.response_json_error("error", "对不起,请先授权登录")
+        store_user_nick = user_nick.split(':')[0]
+        app_info_dict = AppInfoModel(context=self).get_dict("store_user_nick=%s", field="is_gm", params=store_user_nick)
+        if not app_info_dict:
+            is_power = False
+        if app_info_dict["is_gm"] == 1:
             is_power = True
         return self.response_json_success(is_power)
 
 
 class GetAppidByGmHandler(ClientBaseHandler):
     """
-    :description: 获取应用标识
+    :description: GM工具获取应用标识
     """
     @filter_check_params("store_name")
     def get_async(self):
@@ -172,13 +186,20 @@ class GetAppidByGmHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = ""
-        store_user_nick = self.get_user_nick().split(':')[0]
-        if not store_user_nick:
-            return self.response_json_success(app_id)
-        if store_user_nick == config.get_value("test_user_nick"):
-            store_name = self.get_param("store_name")
-            app_base_model = AppBaseModel(context=self)
-            app_id = app_base_model.get_app_id(store_name)
+        store_name = self.get_param("store_name")
+        user_nick = self.get_user_nick()
+        if not user_nick:
+            return self.response_json_error("error", "对不起,请先授权登录")
+        store_user_nick = user_nick.split(':')[0]
+        is_power = False
+        
+        app_info_dict = AppInfoModel(context=self).get_dict("store_user_nick=%s", field="is_gm", params=store_user_nick)
+        if app_info_dict and app_info_dict["is_gm"] == 1:
+            is_power = True
+        if is_power == True:
+            app_info_dict = AppInfoModel(context=self).get_dict("store_name=%s", field="app_id", params=[store_name])
+            if app_info_dict:
+                app_id = app_info_dict["app_id"]
         return self.response_json_success(app_id)
 
 
@@ -193,7 +214,7 @@ class GetShortUrlHandler(ClientBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        access_token = self.get_param("access_token")
+        access_token = self.get_access_token()
         is_log = int(self.get_param("is_log", 0))
         is_log = True if is_log == 1 else False
         url = self.get_param("url")
@@ -221,7 +242,7 @@ class GetHighPowerListHandler(ClientBaseHandler):
         if not user_nick:
             return self.response_json_error("Error", "对不起,请先授权登录")
         store_user_nick = user_nick.split(':')[0]
-        access_token = self.get_param("access_token")
+        access_token = self.get_access_token()
         top_base_model = TopBaseModel(context=self)
         mp_base_model = MPBaseModel(context=self)
         custom_function_list = mp_base_model.get_custom_function_list(store_user_nick)
