@@ -122,7 +122,7 @@ class DeleteIpInfoHandler(ClientBaseHandler):
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ip_base_model = IpBaseModel(context=self)
-        invoke_result_data = ip_base_model.delete_ip_info(app_id, ip_id)
+        invoke_result_data = ip_base_model.update_ip_info_status(app_id, ip_id,1)
         if invoke_result_data.success ==False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         self.create_operation_log(OperationType.delete.value, "ip_info_tb", "DeleteIpInfoHandler", None, ip_id)
