@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2021-11-29 16:39:17
+@LastEditTime: 2021-12-30 13:59:24
 @LastEditors: HuangJianYi
 @Description: 小活动模块（机台）
 """
@@ -151,16 +151,14 @@ class ActModuleListHandler(ClientBaseHandler):
         start_date = self.get_param("start_date")
         end_date = self.get_param("end_date")
 
-        condition = ""
-        params = []
-        order_by = "create_date desc"
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_success({"data": []})
-        else:
-            condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
-            params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
-            order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "sort_index desc,id asc"
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
+        params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
+        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "sort_index desc,id asc"
         if not app_id or not act_id:
             return self.response_json_success({"data": []})
         module_base_model = ModuleBaseModel(context=self)
