@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 14:11:52
-@LastEditTime: 2022-01-20 14:10:36
+@LastEditTime: 2022-04-28 15:03:43
 @LastEditors: HuangJianYi
 @Description: 订单模块
 """
@@ -206,16 +206,18 @@ class UpdatePrizeOrderSellerRemarkHandler(ClientBaseHandler):
         """
         :description: 更新奖品订单卖家备注
         :param app_id：应用标识
+        :param act_id：活动标识
         :param prize_order_id：奖品订单标识
         :param seller_remark：卖家备注
         :return: 
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
+        act_id = int(self.get_param("act_id", 0))
         prize_order_id = int(self.get_param("prize_order_id", 0))
         seller_remark = self.get_param("seller_remark")
         order_base_model = OrderBaseModel(context=self)
-        invoke_result_data = order_base_model.update_prize_order_seller_remark(app_id, prize_order_id, seller_remark)
+        invoke_result_data = order_base_model.update_prize_order_seller_remark(app_id, act_id, prize_order_id, seller_remark)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success()
@@ -230,6 +232,7 @@ class UpdatePrizeOrderStatusHandler(ClientBaseHandler):
         """
         :description: 更新用户奖品订单状态
         :param app_id：应用标识
+        :param act_id：活动标识
         :param prize_order_id：奖品订单标识
         :param order_status：订单状态
         :param express_company：快递公司
@@ -238,6 +241,7 @@ class UpdatePrizeOrderStatusHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
+        act_id = int(self.get_param("act_id", 0))
         prize_order_id = int(self.get_param("prize_order_id", 0))
         order_status = int(self.get_param("order_status", 0))
         express_company = self.get_param("express_company")
@@ -250,7 +254,7 @@ class UpdatePrizeOrderStatusHandler(ClientBaseHandler):
             invoke_result_data.data = {}
         prize_roster_sub_table = invoke_result_data.data["prize_roster_sub_table"] if invoke_result_data.data.__contains__("prize_roster_sub_table") else None
         order_base_model = OrderBaseModel(context=self)
-        invoke_result_data = order_base_model.update_prize_order_status(app_id, prize_order_id, order_status, express_company, express_no, prize_roster_sub_table)
+        invoke_result_data = order_base_model.update_prize_order_status(app_id, act_id, prize_order_id, order_status, express_company, express_no, prize_roster_sub_table)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
