@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-15 11:30:45
-@LastEditTime: 2021-12-02 10:24:07
+@LastEditTime: 2021-12-07 11:07:53
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -20,7 +20,8 @@ class OSS2Helper:
     :return: 
     :last_editors: HuangJianYi
     """
-    def __init__(self):
+    @classmethod
+    def get_oss_config(self):
         oss_config = config.get_value("oss_config")
         if not oss_config:
             oss_config = {}
@@ -46,6 +47,7 @@ class OSS2Helper:
         :return: 
         :last_editors: HuangJianYi
         """
+        self.get_oss_config()
         # 文件名
         file_name = os.path.basename(local_file) if local_file != "" else file_name
 
@@ -104,4 +106,4 @@ class OSS2Helper:
                 os.remove(path)
             except Exception as ex:
                 pass
-        return resource_path
+        return resource_path
\ No newline at end of file
