@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-30 09:22:51
-@LastEditTime: 2021-11-04 10:13:10
+@LastEditTime: 2022-02-18 10:44:29
 @LastEditors: HuangJianYi
 @Description: 排队系统帮助类
 """
@@ -352,7 +352,9 @@ class QueueUpHelper:
                     hash_value_list = []
                     if len(string_list) > 0:
                         for item in string_list:
-                            hash_value_list.append(SevenHelper.json_loads(item))
+                            value = SevenHelper.json_loads(item)
+                            if value:
+                                hash_value_list.append(value)
                     for i in range(len(value_list)):
                         data = value_list[i]
                         hash_value = [hash_value for hash_value in hash_value_list if hash_value["user_id"] == data]
