@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2022-02-28 11:52:22
+@LastEditTime: 2022-04-28 16:23:15
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -12,6 +12,7 @@ from seven_cloudapp_frame.models.db_models.asset.asset_only_model import *
 from seven_cloudapp_frame.models.db_models.user.user_asset_model import *
 from seven_cloudapp_frame.models.db_models.asset.asset_warn_notice_model import *
 from seven_cloudapp_frame.models.seven_model import *
+from seven_cloudapp_frame.models.frame_base_model import *
 
 
 class AssetBaseModel():
@@ -24,7 +25,7 @@ class AssetBaseModel():
         self.logging_link_info = logging_info
 
 
-    def _delete_asset_dependency_key(self, act_id, user_id, delay_delete_time=0.1):
+    def _delete_asset_dependency_key(self, act_id, user_id, delay_delete_time=0.01):
         """
         :description: 删除资产依赖建
         :param act_id: 活动标识
@@ -159,11 +160,11 @@ class AssetBaseModel():
                 #添加唯一标识预警拦截计数,用于控制台跑数据进行并发预警
                 self._add_onlyid_warn_stat(handler_name)
                 return invoke_result_data
-        sub_table_config = config.get_value("sub_table_config",{})
+        frame_base_model = FrameBaseModel(context=self.context)
         db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
-        user_asset_model = UserAssetModel(db_transaction=db_transaction, sub_table=SevenHelper.get_sub_table(act_id, sub_table_config.get("user_asset_num", 0)), context=self.context)
-        asset_log_model = AssetLogModel(db_transaction=db_transaction, sub_table=SevenHelper.get_sub_table(act_id, sub_table_config.get("asset_log_num", 0)), context=self.context)
-        asset_only_model = AssetOnlyModel(db_transaction=db_transaction, sub_table=SevenHelper.get_sub_table(act_id, sub_table_config.get("asset_only_num", 0)), context=self.context)
+        user_asset_model = UserAssetModel(db_transaction=db_transaction, sub_table=frame_base_model.get_business_sub_table("user_asset_tb",{"act_id":act_id,"user_id":0}), context=self.context)
+        asset_log_model = AssetLogModel(db_transaction=db_transaction, sub_table=frame_base_model.get_business_sub_table("asset_log_tb",{"act_id":act_id,"user_id":user_id}), context=self.context)
+        asset_only_model = AssetOnlyModel(db_transaction=db_transaction, sub_table=frame_base_model.get_business_sub_table("asset_only_tb",{"act_id":act_id,"user_id":user_id}), context=self.context)
 
         acquire_lock_name = f"userasset:{user_asset_id_md5}"
         acquire_lock_status, identifier = SevenHelper.redis_acquire_lock(acquire_lock_name)
@@ -344,8 +345,8 @@ class AssetBaseModel():
             else:
                 condition += " AND user_id=%s"
                 params.append(user_ids)
-        sub_table_config = config.get_value("sub_table_config",{})
-        user_asset_model = UserAssetModel(sub_table=SevenHelper.get_sub_table(act_id, sub_table_config.get("user_asset_num", 0)), context=self.context)
+        frame_base_model = FrameBaseModel(context=self.context) 
+        user_asset_model = UserAssetModel(sub_table=frame_base_model.get_business_sub_table("user_asset_tb",{"act_id":act_id,"user_id":0}), context=self.context)
         user_asset_dict_list = user_asset_model.get_dict_list(condition, params=params)
         if len(user_asset_dict_list) > 0:
             for user_asset_dict in user_asset_dict_list:
@@ -369,8 +370,8 @@ class AssetBaseModel():
         """
         if not act_id or not user_id or not asset_type:
             return None
-        sub_table_config = config.get_value("sub_table_config", {})
-        user_asset_model = UserAssetModel(sub_table=SevenHelper.get_sub_table(act_id, sub_table_config.get("user_asset_num", 0)), context=self.context)
+        frame_base_model = FrameBaseModel(context=self.context) 
+        user_asset_model = UserAssetModel(sub_table=frame_base_model.get_business_sub_table("user_asset_tb",{"act_id":act_id,"user_id":0}), context=self.context)
         user_asset_id_md5 = self.get_user_asset_id_md5(act_id, user_id, asset_type, asset_object_id)
         user_asset_dict = user_asset_model.get_dict("id_md5=%s", limit="1", params=[user_asset_id_md5])
         if user_asset_dict:
@@ -442,8 +443,8 @@ class AssetBaseModel():
             else:
                 condition += " AND source_object_id=%s"
                 params.append(source_object_id)
-        sub_table_config = config.get_value("sub_table_config", {})
-        asset_log_model = AssetLogModel(sub_table=SevenHelper.get_sub_table(act_id, sub_table_config.get("asset_log_num", 0)), context=self.context)
+        frame_base_model = FrameBaseModel(context=self.context)
+        asset_log_model = AssetLogModel(sub_table=frame_base_model.get_business_sub_table("asset_log_tb",{"act_id":act_id,"user_id":user_id}), context=self.context)
         if is_cache:
             page_list, total = asset_log_model.get_cache_dict_page_list(field, page_index, page_size, condition, order_by="create_date desc", params=params,dependency_key=f"asset_log_list:actid_{act_id}_userid_{user_id}")
         else:
@@ -456,6 +457,60 @@ class AssetBaseModel():
         page_info = PageInfo(page_index, page_size, total, page_list)
         return page_info
 
+    def add_asset_log(self, app_id, act_id, module_id, user_id, open_id, user_nick, asset_type, asset_value, asset_object_id, source_type, source_object_id, source_object_name, log_title, sub_table=None, history_asset_value=0, handler_name="", request_code="", info_json={}):
+        """
+        :description: 添加资产流水
+        :param act_id：活动标识
+        :param module_id：模块标识，没有填0
+        :param user_id：用户标识
+        :param open_id：open_id
+        :param user_nick：昵称
+        :param asset_type：资产类型(1-次数2-积分3-价格档位)
+        :param asset_value：变动的资产值，算好差值传入
+        :param asset_object_id：资产对象标识
+        :param source_type：来源类型（1-购买2-任务3-手动配置4-抽奖5-回购）
+        :param source_object_id：来源对象标识(比如来源类型是任务则对应任务类型)
+        :param source_object_name：来源对象名称(比如来源类型是任务则对应任务名称)
+        :param log_title：资产流水标题
+        :param sub_table：资产流水分表名
+        :param history_asset_value:历史资产值
+        :param handler_name:接口名称
+        :param request_code:请求唯一标识，从seven_framework框架获取对应request_code
+        :param info_json：资产流水详情，用于存放业务方自定义字典
+        :return: 返回实体InvokeResultData
+        :last_editors: HuangJianYi
+        """
+        asset_value = int(asset_value)
+        if sub_table:
+            asset_log_model = AssetLogModel(sub_table=sub_table, context=self.context)
+        else:
+            frame_base_model = FrameBaseModel(context=self.context)
+            asset_log_model = AssetLogModel(sub_table=frame_base_model.get_business_sub_table("asset_log_tb",{"act_id":act_id,"user_id":user_id}), context=self.context)
+        asset_log = AssetLog()
+        asset_log.app_id = app_id
+        asset_log.act_id = act_id
+        asset_log.module_id = module_id
+        asset_log.user_id = user_id
+        asset_log.open_id = open_id
+        asset_log.user_nick = user_nick
+        asset_log.log_title = log_title
+        asset_log.info_json = info_json if info_json else {}
+        asset_log.asset_type = asset_type
+        asset_log.asset_object_id = asset_object_id
+        asset_log.source_type = source_type
+        asset_log.source_object_id = source_object_id
+        asset_log.source_object_name = source_object_name
+        asset_log.only_id = ""
+        asset_log.operate_type = 0 if asset_value > 0 else 1
+        asset_log.operate_value = asset_value
+        asset_log.history_value = history_asset_value
+        asset_log.now_value = history_asset_value + asset_value
+        asset_log.handler_name = handler_name
+        asset_log.request_code = request_code
+        asset_log.create_date = SevenHelper.get_now_datetime()
+        asset_log.create_day = SevenHelper.get_now_day_int()
+        asset_log_model.add_entity(asset_log)
+
     def get_asset_warn_list(self, app_id, act_id,  asset_type, page_size=20, page_index=0,user_id=0,asset_object_id="", start_date="", end_date="", user_nick="", open_id="", field="*"):
         """
         :description: 获取资产预警记录
