@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-11-24 09:36:39
-@LastEditTime: 2022-03-01 17:50:17
+@LastEditTime: 2022-04-28 14:59:32
 @LastEditors: HuangJianYi
 @Description: ERP控制台业务模型(用于跟遁甲系统对接，推送订单和回写物流) 需在配置文件加 armor_url 和 armor_sign_key对应的值
 """
@@ -11,9 +11,11 @@ import threading, multiprocessing
 from seven_framework import *
 from seven_framework.console.base_console import *
 from seven_cloudapp_frame.libs.customize.seven_helper import *
+from seven_cloudapp_frame.models.frame_base_model import FrameBaseModel
 from seven_cloudapp_frame.models.db_models.erp.erp_relation_model import *
 from seven_cloudapp_frame.models.db_models.prize.prize_order_model import *
 from seven_cloudapp_frame.models.db_models.prize.prize_roster_model import *
+from seven_cloudapp_frame.models.db_models.act.act_info_model import *
 
 
 class ErpConsoleModel():
@@ -53,9 +55,9 @@ class ErpConsoleModel():
         while True:
             try:
                 time.sleep(0.1)
-                prize_order_model = PrizeOrderModel()
-                prize_roster_model = PrizeRosterModel()
                 erp_relation_model = ErpRelationModel()
+                act_info_model = ActInfoModel()
+                frame_base_model = FrameBaseModel(None)
                 now_date = TimeHelper.get_now_format_time()
                 if mod_count == 1:
                     erp_relation_list = erp_relation_model.get_dict_list("is_release=1 and %s>sync_date and start_date<=%s and end_date>=%s", order_by="sync_date asc", limit="100", params=[TimeHelper.add_minutes_by_format_time(minute=-10), now_date, now_date])
@@ -65,28 +67,32 @@ class ErpConsoleModel():
                     for erp_relation_dict in erp_relation_list:
                         try:
                             erp_relation_model.update_table("sync_date=%s", "id=%s", params=[TimeHelper.get_now_format_time(), erp_relation_dict["id"]])
-
-                            condition = "app_id=%s and order_status=0 and sync_status=0"
-                            params = [erp_relation_dict["app_id"]]
-                            record_count = prize_order_model.get_total(condition, params=params)
-                            page_count = SevenHelper.get_page_count(page_size, record_count)
-                            for page_index in range(page_count):
-                                prize_order_list_dict, total = prize_order_model.get_dict_page_list("*", page_index, page_size, condition, "", "id asc", params)
-                                for prize_order_dict in prize_order_list_dict:
-                                    request_params = self.compose_push_request_params(sign_key, erp_relation_dict, prize_order_dict, prize_roster_model)
-                                    request_params = self.process_order_push_executed(request_params, erp_relation_dict)
-                                    if request_params["goods"]:
-                                        result = HTTPHelper.post(push_url, request_params, {"Content-Type": "application/json"})
-                                        if result and result.ok:
-                                            prize_order_model.update_table("sync_status=1,sync_date=%s", "id=%s", params=[TimeHelper.get_now_format_time(), prize_order_dict["id"]])
-                                        else:
-                                            prize_order_dict["sync_count"] = prize_order_dict["sync_count"] + 1
-                                            if prize_order_dict["sync_count"] == 10:
-                                                prize_order_model.update_table("sync_status=2,sync_date=%s,sync_result=%s", "id=%s", params=[TimeHelper.get_now_format_time(), result, prize_order_dict["id"]])
+                            act_info_dict_list = act_info_model.get_dict_list("app_id=%s and is_release=1", field="id", params=[erp_relation_dict["app_id"]])
+                            if len(act_info_dict_list) > 0:
+                                for act_info_dict in act_info_dict_list:
+                                    prize_order_model = PrizeOrderModel(sub_table=frame_base_model.get_business_sub_table("prize_order_tb", {"act_id": act_info_dict["id"], "user_id": 0}))
+                                    prize_roster_model = PrizeRosterModel(sub_table=frame_base_model.get_business_sub_table("prize_roster_tb", {"act_id": act_info_dict["id"], "user_id": 0}))
+                                    condition = "app_id=%s and order_status=0 and sync_status=0"
+                                    params = [erp_relation_dict["app_id"]]
+                                    record_count = prize_order_model.get_total(condition, params=params)
+                                    page_count = SevenHelper.get_page_count(page_size, record_count)
+                                    for page_index in range(page_count):
+                                        prize_order_list_dict, total = prize_order_model.get_dict_page_list("*", page_index, page_size, condition, "", "id asc", params)
+                                        for prize_order_dict in prize_order_list_dict:
+                                            request_params = self.compose_push_request_params(sign_key, erp_relation_dict, prize_order_dict, prize_roster_model)
+                                            request_params = self.process_order_push_executed(request_params, erp_relation_dict)
+                                            if request_params["goods"]:
+                                                result = HTTPHelper.post(push_url, request_params, {"Content-Type": "application/json"})
+                                                if result and result.ok:
+                                                    prize_order_model.update_table("sync_status=1,sync_date=%s", "id=%s", params=[TimeHelper.get_now_format_time(), prize_order_dict["id"]])
+                                                else:
+                                                    prize_order_dict["sync_count"] = prize_order_dict["sync_count"] + 1
+                                                    if prize_order_dict["sync_count"] == 10:
+                                                        prize_order_model.update_table("sync_status=2,sync_date=%s,sync_result=%s", "id=%s", params=[TimeHelper.get_now_format_time(), result, prize_order_dict["id"]])
+                                                    else:
+                                                        prize_order_model.update_table("sync_count=sync_count+1,sync_date=%s,sync_result=%s", "id=%s", params=[TimeHelper.get_now_format_time(), result, prize_order_dict["id"]])
                                             else:
-                                                prize_order_model.update_table("sync_count=sync_count+1,sync_date=%s,sync_result=%s", "id=%s", params=[TimeHelper.get_now_format_time(), result, prize_order_dict["id"]])
-                                    else:
-                                        prize_order_model.update_table("sync_status=2,sync_date=%s,sync_result=%s", "id=%s", params=[TimeHelper.get_now_format_time(), "推送订单失败，没有商品信息", prize_order_dict["id"]])
+                                                prize_order_model.update_table("sync_status=2,sync_date=%s,sync_result=%s", "id=%s", params=[TimeHelper.get_now_format_time(), "推送订单失败，没有商品信息", prize_order_dict["id"]])
                         except Exception as ex:
                             logger_error.error(f"推送订单队列{mod_value}异常,json串:{SevenHelper.json_dumps(erp_relation_dict)},ex:{traceback.format_exc()}")
                             continue
@@ -116,6 +122,7 @@ class ErpConsoleModel():
         data["mini_order"] = prize_order_dict["order_no"]
         data["user_account"] = prize_order_dict["user_nick"]
         data["order_time"] = TimeHelper.datetime_to_timestamp(prize_order_dict["create_date"]) * 1000 if str(prize_order_dict["create_date"]) != "1900-01-01 00:00:00" else 0
+        data["activity_id"] = prize_order_dict["act_id"]
         data["activity_name"] = ""
         data["order_price"] = str(prize_order_dict['order_price'])
         data["consignee"] = prize_order_dict["real_name"]
@@ -172,9 +179,8 @@ class ErpConsoleModel():
         :return: 
         :last_editors: HuangJianYi
         """
-        prize_order_model = PrizeOrderModel()
-        prize_roster_model = PrizeRosterModel()
         erp_relation_model = ErpRelationModel()
+        frame_base_model = FrameBaseModel(None)
 
         erp_redis_init = SevenHelper.redis_init(config_dict=config.get_value("erp_redis"))
 
@@ -205,6 +211,9 @@ class ErpConsoleModel():
                                     if not order_info_json:
                                         break
                                     order_info_dict = json.loads(order_info_json)
+                                    act_id = int(order_info_dict["activity_id"]) if order_info_dict["activity_id"] else 0
+                                    prize_order_model = PrizeOrderModel(sub_table=frame_base_model.get_business_sub_table("prize_order_tb", {"act_id": act_id, "user_id": 0}))
+                                    prize_roster_model = PrizeRosterModel(sub_table=frame_base_model.get_business_sub_table("prize_roster_tb", {"act_id": act_id, "user_id": 0}))
                                     order_status = order_info_dict["order_status"]
                                     order_no = order_info_dict["mini_order"]
                                     express_no = order_info_dict["logistics_number"]
