@@ -2,13 +2,16 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-19 13:37:16
-@LastEditTime: 2022-02-28 13:46:34
+@LastEditTime: 2022-04-29 16:11:57
 @LastEditors: HuangJianYi
 @Description: 
 """
 import threading, multiprocessing
 from seven_framework.console.base_console import *
+from seven_cloudapp_frame.models.seven_model import InvokeResultData
+from seven_cloudapp_frame.models.frame_base_model import FrameBaseModel
 from seven_cloudapp_frame.libs.customize.seven_helper import *
+from seven_cloudapp_frame.models.console_models.timing_work_model import *
 from seven_cloudapp_frame.models.db_models.stat.stat_queue_model import *
 from seven_cloudapp_frame.models.db_models.stat.stat_orm_model import *
 from seven_cloudapp_frame.models.db_models.stat.stat_report_model import *
@@ -29,41 +32,35 @@ class StatConsoleModel():
 
         stat_process_ways = config.get_value("stat_process_ways","mysql")
         if stat_process_ways == "mysql":
-            sub_table_count = config.get_value("stat_sub_table_count", 0)
-            if sub_table_count == 0:
-                self._start_process_stat_queue(None, mod_count)
-            else:
-                for i in range(sub_table_count):
-                    self._start_process_stat_queue(str(i), mod_count)
+            for i in range(mod_count):
+                t = threading.Thread(target=self._process_stat_queue, args=[i, mod_count])
+                t.start()
         else:
-            self._start_process_redis_stat_queue(10)
+            for i in range(10):
+                j = threading.Thread(target=self._process_redis_stat_queue, args=[i])
+                j.start()
 
-    def _start_process_stat_queue(self, sub_table, mod_count):
+        clea_data_work = ClearDataWork()
+        clea_data_work.start_hours = 1
+        clea_data_work.end_hours = 1
+        clea_data_work.sleep_time = 3600
+        clea_data_work.start_work("清理统计流水数据作业")
 
-        for i in range(mod_count):
-            t = threading.Thread(target=self._process_stat_queue, args=[sub_table, i, mod_count])
-            t.start()
-
-    def _process_stat_queue(self, sub_table, mod_value, mod_count):
+    def _process_stat_queue(self, mod_value, mod_count):
         """
         :description: 处理mysql统计队列
-        :param sub_table: 分表名称
         :param mod_value: 当前队列值
         :param mod_count: 队列数
         :return: 
         :last_editors: HuangJianYi
         """
         print(f"{TimeHelper.get_now_format_time()} 统计队列{mod_value}启动")
-
         while True:
             try:
                 time.sleep(0.1)
                 db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
-                stat_queue_model = StatQueueModel(sub_table=sub_table, db_transaction=db_transaction)
-                del_stat_queue_sub_table = sub_table + "_del" if sub_table else "del"
-                del_stat_queue_model = StatQueueModel(sub_table=del_stat_queue_sub_table, db_transaction=db_transaction)
-                stat_log_model = StatLogModel(sub_table=sub_table, db_transaction=db_transaction)
-                stat_report_model = StatReportModel(sub_table=sub_table,db_transaction=db_transaction)
+                stat_queue_model = StatQueueModel(db_transaction=db_transaction)
+                del_stat_queue_model = StatQueueModel(sub_table="del", db_transaction=db_transaction)
                 stat_orm_model = StatOrmModel()
                 now_date = TimeHelper.get_now_format_time()
                 if mod_count == 1:
@@ -73,6 +70,9 @@ class StatConsoleModel():
                 if len(stat_queue_list) > 0:
                     for stat_queue in stat_queue_list:
                         try:
+                            frame_base_model = FrameBaseModel(None)
+                            stat_log_model = StatLogModel(sub_table=frame_base_model.get_business_sub_table("stat_log_tb", {"act_id": stat_queue.act_id, "user_id": stat_queue.user_id}), db_transaction=db_transaction)
+                            stat_report_model = StatReportModel(sub_table=frame_base_model.get_business_sub_table("stat_report_tb", {"act_id": stat_queue.act_id, "user_id": 0}), db_transaction=db_transaction)
                             stat_orm = stat_orm_model.get_cache_entity("((act_id=%s and module_id=%s) or (act_id=0 and module_id=0)) and key_name=%s", params=[stat_queue.act_id, stat_queue.module_id, stat_queue.key_name])
                             if not stat_orm:
                                 stat_queue_model.del_entity("id=%s", params=[stat_queue.id])
@@ -84,9 +84,9 @@ class StatConsoleModel():
                             is_add = True
                             if stat_orm.repeat_type > 0:
                                 if stat_orm.repeat_type == 2:
-                                    stat_log_total = stat_log_model.get_cache_total("app_id=%s and act_id=%s and module_id=%s and orm_id=%s and user_id=%s", params=[stat_queue.app_id, stat_queue.act_id, stat_queue.module_id, stat_orm.id, stat_queue.user_id])
+                                    stat_log_total = stat_log_model.get_cache_total("act_id=%s and module_id=%s and orm_id=%s and user_id=%s", params=[stat_queue.act_id, stat_queue.module_id, stat_orm.id, stat_queue.user_id])
                                 else:
-                                    stat_log_total = stat_log_model.get_cache_total("app_id=%s and act_id=%s and module_id=%s and orm_id=%s and user_id=%s and create_day=%s", params=[stat_queue.app_id, stat_queue.act_id, stat_queue.module_id, stat_orm.id, stat_queue.user_id, create_day_int])
+                                    stat_log_total = stat_log_model.get_cache_total("act_id=%s and module_id=%s and orm_id=%s and user_id=%s and create_day=%s", params=[stat_queue.act_id, stat_queue.module_id, stat_orm.id, stat_queue.user_id, create_day_int])
                                 if stat_log_total > 0:
                                     is_add = False
 
@@ -102,8 +102,8 @@ class StatConsoleModel():
                             stat_log.create_month = create_month_int
                             stat_log.create_date = create_date
 
-                            stat_report_condition = "app_id=%s and act_id=%s and module_id=%s and key_name=%s and create_day=%s"
-                            stat_report_param = [stat_queue.app_id, stat_queue.act_id, stat_queue.module_id, stat_queue.key_name, create_day_int]
+                            stat_report_condition = "act_id=%s and module_id=%s and key_name=%s and create_day=%s"
+                            stat_report_param = [stat_queue.act_id, stat_queue.module_id, stat_queue.key_name, create_day_int]
                             stat_report_total = stat_report_model.get_cache_total(stat_report_condition, params=stat_report_param)
 
                             db_transaction.begin_transaction()
@@ -142,12 +142,6 @@ class StatConsoleModel():
                 logger_error.error(f"统计队列{mod_value}异常,ex:{traceback.format_exc()}")
                 time.sleep(5)
 
-    def _start_process_redis_stat_queue(self, mod_count):
-
-        for i in range(mod_count):
-            t = threading.Thread(target=self._process_redis_stat_queue, args=[i])
-            t.start()
-
     def _process_redis_stat_queue(self, mod_value):
         """
         :description: 处理redis统计队列
@@ -168,9 +162,9 @@ class StatConsoleModel():
                     continue
                 try:
                     stat_queue_dict = SevenHelper.json_loads(stat_queue_json)
-                    sub_table_config = config.get_value("sub_table_config", {})
-                    stat_log_model = StatLogModel(sub_table=SevenHelper.get_sub_table(stat_queue_dict["act_id"], sub_table_config.get("stat_log_num", 0)), db_transaction=db_transaction)
-                    stat_report_model = StatReportModel(sub_table=SevenHelper.get_sub_table(stat_queue_dict["act_id"], sub_table_config.get("stat_report_num", 0)), db_transaction=db_transaction)
+                    frame_base_model = FrameBaseModel(context=self.context)
+                    stat_log_model = StatLogModel(sub_table=frame_base_model.get_business_sub_table("stat_log_tb", {"act_id": stat_queue_dict["act_id"], "user_id": stat_queue_dict["user_id"]}), db_transaction=db_transaction)
+                    stat_report_model = StatReportModel(sub_table=frame_base_model.get_business_sub_table("stat_report_tb", {"act_id": stat_queue_dict["act_id"], "user_id": 0}), db_transaction=db_transaction)
                     stat_orm = stat_orm_model.get_cache_entity("((act_id=%s and module_id=%s) or (act_id=0 and module_id=0)) and key_name=%s", params=[stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_queue_dict["key_name"]])
                     if not stat_orm:
                         continue
@@ -181,9 +175,9 @@ class StatConsoleModel():
                     is_add = True
                     if stat_orm.repeat_type > 0:
                         if stat_orm.repeat_type == 2:
-                            stat_log_total = stat_log_model.get_cache_total("app_id=%s and act_id=%s and module_id=%s and orm_id=%s and user_id=%s", params=[stat_queue_dict["app_id"],stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_orm.id, stat_queue_dict["user_id"]])
+                            stat_log_total = stat_log_model.get_cache_total("act_id=%s and module_id=%s and orm_id=%s and user_id=%s", params=[stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_orm.id, stat_queue_dict["user_id"]])
                         else:
-                            stat_log_total = stat_log_model.get_cache_total("app_id=%s and act_id=%s and module_id=%s and orm_id=%s and user_id=%s and create_day=%s", params=[stat_queue_dict["app_id"], stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_orm.id, stat_queue_dict["user_id"], create_day_int])
+                            stat_log_total = stat_log_model.get_cache_total("act_id=%s and module_id=%s and orm_id=%s and user_id=%s and create_day=%s", params=[stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_orm.id, stat_queue_dict["user_id"], create_day_int])
                         if stat_log_total > 0:
                             is_add = False
 
@@ -199,8 +193,8 @@ class StatConsoleModel():
                     stat_log.create_month = create_month_int
                     stat_log.create_date = create_date
 
-                    stat_report_condition = "app_id=%s and act_id=%s and module_id=%s and key_name=%s and create_day=%s"
-                    stat_report_param = [stat_queue_dict["app_id"], stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_queue_dict["key_name"], create_day_int]
+                    stat_report_condition = "act_id=%s and module_id=%s and key_name=%s and create_day=%s"
+                    stat_report_param = [stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_queue_dict["key_name"], create_day_int]
                     stat_report_total = stat_report_model.get_cache_total(stat_report_condition, params=stat_report_param)
 
                     if is_add:
@@ -236,3 +230,27 @@ class StatConsoleModel():
             except Exception as ex:
                 logger_error.error(f"统计队列{mod_value}异常,ex:{traceback.format_exc()}")
                 time.sleep(5)
+
+class ClearDataWork(TimingWork):
+    """
+    :description: 清理数据
+    :return: 
+    :last_editors: HuangJianYi
+    """
+    def execute(self):
+        invoke_result_data = InvokeResultData()
+        stat_log_model = StatLogModel()
+        stat_orm_model = StatOrmModel()
+        page_index = 0
+        while True:
+            stat_orm_dict_list,total =  stat_orm_model.get_dict_page_list(field="id,repeat_type",page_index=page_index,page_size=50,order_by="id asc")
+            if len(stat_orm_dict_list) <=0:
+                break
+            for stat_orm_dict in stat_orm_dict_list:
+                if stat_orm_dict["repeat_type"] != 2:
+                    while True:
+                        is_del = stat_log_model.del_entity("orm_id=%s and create_day<%s", params=[stat_orm_dict["id"], SevenHelper.get_now_day_int(-24 * 15)], limit="1000")
+                        if is_del == False:
+                            break
+            page_index += 1
+        return invoke_result_data
