@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-27 10:59:46
-@LastEditTime: 2021-08-25 10:05:45
+@LastEditTime: 2021-11-29 14:10:53
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -30,7 +30,7 @@ class ActPrize:
         self.app_id = ""  # 应用标识
         self.act_id = 0  # 活动标识
         self.module_id = 0  # 活动模块标识
-        self.ascription_type = 0  # 奖品归属类型（0-活动奖品1-任务奖品）
+        self.ascription_type = 0  # 奖品归属类型（0-活动奖品1-任务奖品2-兑换奖品）业务自定义从101开始
         self.prize_name = ""  # 奖品名称
         self.prize_title = ""  # 奖品子标题
         self.prize_pic = ""  # 奖品图
