@@ -2,16 +2,17 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-15 17:17:08
-@LastEditTime: 2021-09-09 17:31:11
+@LastEditTime: 2021-10-11 16:24:40
 @LastEditors: HuangJianYi
 @Description: 
 """
 #此文件由rigger自动生成
 from seven_framework.mysql import MySQLHelper
 from seven_framework.base_model import *
+from seven_cloudapp_frame.models.cache_model import *
 
 
-class AssetLogModel(BaseModel):
+class AssetLogModel(CacheModel):
     def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
         super(AssetLogModel, self).__init__(AssetLog, sub_table)
         self.db = MySQLHelper(config.get_value(db_connect_key))
