@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-11 09:10:33
-@LastEditTime: 2022-01-24 11:03:40
+@LastEditTime: 2022-04-27 16:12:17
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -144,6 +144,28 @@ class FrameBaseModel():
         else:
             return "交易成功"
 
+    def get_business_sub_table(self, key, param_dict):
+        """
+        :description: 获取分表名称
+        :param key:字典key
+        :param param_dict:参数字典
+        :return:
+        :last_editors: HuangJianYi
+        """
+        if not param_dict or not key:
+            return None    
+        sub_table_config_list = config.get_value("sub_table_config_list",{})
+        sub_table_config = sub_table_config_list.get(key,{"sub_count":0,"sub_ways":0}) #sub_count分表数量，sub_ways分表方式（0-默认1-活动id取模2-用户id取模）
+        sub_ways = sub_table_config.get("sub_ways", 0)
+        if sub_ways == 1:
+            object_id = int(param_dict.get("act_id",0))
+        if sub_ways == 2:
+            object_id = int(param_dict.get("user_id",0))
+        else:
+            object_id = 0
+        
+        return SevenHelper.get_sub_table(object_id, sub_table_config.get("sub_count", 0))
+        
     def business_process_executing(self,app_id,act_id,module_id,user_id,login_token,handler_name,check_new_user=False,check_user_nick=True,continue_request_expire=5,acquire_lock_name="",request_limit_num=0,request_limit_time=1,source_object_id=""):
         """
         :description: 业务执行前事件,核心业务如抽奖、做任务需要调用当前方法
@@ -167,8 +189,8 @@ class FrameBaseModel():
 
         if not act_id or not user_id or not login_token or not handler_name:
             invoke_result_data.success = False
-            invoke_result_data.error_code = "参数不能为空或等于0"
-            invoke_result_data.error_message = f""
+            invoke_result_data.error_code = "param_error"
+            invoke_result_data.error_message = "参数不能为空或等于0"
             return invoke_result_data
 
         #请求太频繁限制
@@ -237,7 +259,7 @@ class FrameBaseModel():
                     invoke_result_data.error_message = "活动已结束"
                     return invoke_result_data
 
-        user_info_model = UserInfoModel(context=self.context)
+        user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb", {"act_id": act_info_dict["id"], "user_id": 0}),context=self.context)
         id_md5 = CryptoHelper.md5_encrypt_int(f"{act_id}_{user_id}")
         user_info_dict = user_info_model.get_cache_dict("id_md5=%s", limit="1", params=[id_md5], dependency_key=f"user_info:actid_{act_id}_idmd5_{id_md5}")
         if not user_info_dict:
@@ -311,3 +333,67 @@ class FrameBaseModel():
             SevenHelper.redis_release_lock(acquire_lock_name,identifier)
         if request_queue_name:
             SevenHelper.redis_lpop(request_queue_name)
+
+    def process_malice_request(self,handler_name,user_id,ip="",user_request_limit_num=30,ip_request_limit_num=30,cycle_type=1,limit_request_time=24):
+        """
+        :description: 处理恶意请求
+        :param handler_name:接口名称
+        :param user_id:用户标识
+        :param ip:用户ip
+        :param user_request_limit_num:用户请求上限数
+        :param ip_request_limit_num:ip请求上限数
+        :param cycle_type:累计周期类型(1-每分钟 2-每小时 3-每天)
+        :param limit_request_time:限制请求时间(单位小时)
+        :return:InvokeResultData
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        if (not user_id and not ip) or not handler_name:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "param_error"
+            invoke_result_data.error_message = "参数不能为空或等于0"
+            return invoke_result_data
+        redis_init = SevenHelper.redis_init()
+        if user_id:
+            objectid_key = f"malice_request:objectid_1_{handler_name}_{user_id}"
+            count_key = f"malice_request:count_1_{handler_name}_{user_id}"
+            objectid_value = redis_init.get(objectid_key)
+            if objectid_value:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "malice_request_1"
+                invoke_result_data.error_message = "异常操作请稍后再试"
+                return invoke_result_data
+            count_value = redis_init.get(count_key)
+            count_value = int(count_value) if count_value else 0
+            if count_value >= user_request_limit_num:
+                redis_init.set(objectid_key, 1, limit_request_time * 60 * 60)
+            redis_init.incr(count_key, 1)
+            if cycle_type == 1:
+                redis_init.expire(count_key, 60)
+            elif cycle_type == 2:
+                redis_init.expire(count_key, 60*60)
+            else:
+                redis_init.expire(count_key, 24*60*60)
+        if ip:
+            objectid_key = f"malice_request:objectid_2_{handler_name}_{ip}"
+            count_key = f"malice_request:count_2_{handler_name}_{ip}"
+            objectid_value = redis_init.get(objectid_key)
+            if objectid_value:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "malice_request_2"
+                invoke_result_data.error_message = "异常操作请稍后再试"
+                return invoke_result_data
+            count_value = redis_init.get(count_key)
+            count_value = int(count_value) if count_value else 0
+            if count_value >= ip_request_limit_num:
+                redis_init.set(objectid_key, 1, limit_request_time * 60 * 60)
+            redis_init.incr(count_key, 1)
+            if cycle_type == 1:
+                redis_init.expire(count_key, 60)
+            elif cycle_type == 2:
+                redis_init.expire(count_key, 60*60)
+            else:
+                redis_init.expire(count_key, 24*60*60)
+        return invoke_result_data
+        
+
