@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 09:24:43
-@LastEditTime: 2022-02-25 14:17:05
+@LastEditTime: 2022-04-28 15:05:14
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -44,7 +44,7 @@ class OrderBaseModel(FrameBaseModel):
         dependency_key = f"prize_order_list:actid_{act_id}"
         if user_id:
             dependency_key += f"_userid_{user_id}"
-        PrizeOrderModel().delete_dependency_key(dependency_key, delay_delete_time)
+        PrizeOrderModel(sub_table=self.get_business_sub_table("prize_order_tb", {"act_id": act_id, "user_id": 0})).delete_dependency_key(dependency_key, delay_delete_time)
         
 
     def _delete_prize_roster_dependency_key(self, act_id, user_id, delay_delete_time=0.1):
@@ -59,7 +59,8 @@ class OrderBaseModel(FrameBaseModel):
         dependency_key = f"prize_roster_list:actid_{act_id}"
         if user_id:
             dependency_key += f"_userid_{user_id}"
-        PrizeRosterModel().delete_dependency_key(dependency_key, delay_delete_time)
+        
+        PrizeRosterModel(sub_table=self.get_business_sub_table("prize_roster_tb", {"act_id": act_id, "user_id": 0})).delete_dependency_key(dependency_key, delay_delete_time)
 
 
     def get_prize_order_list(self, app_id, act_id, user_id, open_id, nick_name, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size=20, page_index=0, order_by="create_date desc", field="*", is_search_roster=False, is_cache=True, condition="", params=[], prize_roster_sub_table=None):
@@ -129,7 +130,7 @@ class OrderBaseModel(FrameBaseModel):
         if create_date_end:
             where += " AND create_date<=%s"
             params_list.append(create_date_end)
-        prize_order_model = PrizeOrderModel(context=self.context)
+        prize_order_model = PrizeOrderModel(sub_table=self.get_business_sub_table("prize_order_tb", {"act_id": act_id, "user_id": 0}),context=self.context)
         if is_cache:
             dependency_key=f"prize_order_list:actid_{act_id}"
             if user_id:
@@ -138,6 +139,8 @@ class OrderBaseModel(FrameBaseModel):
         else:
             page_list, total = prize_order_model.get_dict_page_list(field, page_index, page_size, where, "", order_by, params_list)
         if is_search_roster == True:
+            if not prize_roster_sub_table:
+                prize_roster_sub_table = self.get_business_sub_table("prize_roster_tb", {"act_id": act_id, "user_id": 0})
             prize_roster_model = PrizeRosterModel(context=self.context, sub_table=prize_roster_sub_table)
             if page_list and len(page_list)>0:
                 order_no_list = [str(i['order_no']) for i in page_list]
@@ -148,10 +151,11 @@ class OrderBaseModel(FrameBaseModel):
         page_info = PageInfo(page_index, page_size, total, page_list)
         return page_info
 
-    def update_prize_order_status(self,app_id,prize_order_id,order_status,express_company="",express_no="",prize_roster_sub_table=None):
+    def update_prize_order_status(self,app_id,act_id,prize_order_id,order_status,express_company="",express_no="",prize_roster_sub_table=None):
         """
         :description: 更新用户奖品订单状态
         :param app_id：应用标识
+        :param act_id：活动标识
         :param prize_order_id：奖品订单标识
         :param order_status：订单状态
         :param express_company：快递公司
@@ -160,9 +164,11 @@ class OrderBaseModel(FrameBaseModel):
         :return: 实体模型InvokeResultData
         :last_editors: HuangJianYi
         """
+        if not prize_roster_sub_table:
+            prize_roster_sub_table = self.get_business_sub_table("prize_roster_tb", {"act_id": act_id, "user_id": 0})
         now_datetime = SevenHelper.get_now_datetime()
         db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
-        prize_order_model = PrizeOrderModel(context=self.context, db_transaction=db_transaction)
+        prize_order_model = PrizeOrderModel(sub_table=self.get_business_sub_table("prize_order_tb", {"act_id": act_id, "user_id": 0}),context=self.context, db_transaction=db_transaction)
         prize_roster_model = PrizeRosterModel(context=self.context, sub_table=prize_roster_sub_table, db_transaction=db_transaction)
         invoke_result_data = InvokeResultData()
 
@@ -217,17 +223,18 @@ class OrderBaseModel(FrameBaseModel):
 
         return invoke_result_data
 
-    def update_prize_order_seller_remark(self,app_id,prize_order_id,seller_remark):
+    def update_prize_order_seller_remark(self,app_id,act_id,prize_order_id,seller_remark):
         """
         :description: 更新用户奖品订单卖家备注
         :param app_id：应用标识
+        :param act_id：活动标识
         :param prize_order_id：奖品订单标识
         :param seller_remark：卖家备注
         :return: 实体模型InvokeResultData
         :last_editors: HuangJianYi
         """
         now_datetime = SevenHelper.get_now_datetime()
-        prize_order_model = PrizeOrderModel(context=self.context)
+        prize_order_model = PrizeOrderModel(sub_table=self.get_business_sub_table("prize_order_tb", {"act_id": act_id, "user_id": 0}),context=self.context)
         invoke_result_data = InvokeResultData()
 
         prize_order = prize_order_model.get_entity_by_id(prize_order_id)
@@ -262,6 +269,8 @@ class OrderBaseModel(FrameBaseModel):
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message ="无效活动,无法导入订单"
             return invoke_result_data
+        if not prize_roster_sub_table:
+            prize_roster_sub_table = self.get_business_sub_table("prize_roster_tb", {"act_id": act_id, "user_id": 0})
         prize_order_model = PrizeOrderModel(context=self.context)
         prize_roster_model = PrizeRosterModel(context=self.context, sub_table=prize_roster_sub_table)
         data = []
@@ -405,9 +414,9 @@ class OrderBaseModel(FrameBaseModel):
             invoke_result_data.error_message ="无效活动,无法创建订单"
             return invoke_result_data
         db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
-        user_info_model = UserInfoModel(db_transaction=db_transaction, context=self.context)
-        prize_roster_model = PrizeRosterModel(db_transaction=db_transaction, context=self.context)
-        prize_order_model = PrizeOrderModel(db_transaction=db_transaction, context=self.context)
+        user_info_model = UserInfoModel(db_transaction=db_transaction,sub_table=self.get_business_sub_table("user_info_tb", {"act_id": act_id, "user_id": 0}), context=self.context)
+        prize_roster_model = PrizeRosterModel(db_transaction=db_transaction,sub_table=self.get_business_sub_table("prize_roster_tb", {"act_id": act_id, "user_id": 0}), context=self.context)
+        prize_order_model = PrizeOrderModel(db_transaction=db_transaction,sub_table=self.get_business_sub_table("prize_order_tb", {"act_id": act_id, "user_id": 0}), context=self.context)
         prize_ids_list = []
         if prize_ids:
             prize_ids_list = prize_ids.split(',')
@@ -458,7 +467,7 @@ class OrderBaseModel(FrameBaseModel):
         else:
             prize_roster_list = prize_roster_model.get_list("act_id=%s and prize_status=0")
 
-        prize_order_model = PrizeOrderModel(context=self.context)
+        prize_order_model = PrizeOrderModel(sub_table=self.get_business_sub_table("prize_order_tb", {"act_id": act_id, "user_id": 0}),context=self.context)
         now_date = SevenHelper.get_now_datetime()
         prize_order = PrizeOrder()
         prize_order.app_id = app_id
@@ -803,7 +812,7 @@ class OrderBaseModel(FrameBaseModel):
             where += " AND create_date<=%s"
             params_list.append(create_date_end)
 
-        prize_roster_model = PrizeRosterModel(context=self.context)
+        prize_roster_model = PrizeRosterModel(sub_table=self.get_business_sub_table("prize_roster_tb", {"act_id": act_id, "user_id": 0}),context=self.context)
         if is_cache:
             dependency_key = f"prize_roster_list:actid_{act_id}"
             if user_id:
@@ -841,7 +850,7 @@ class OrderBaseModel(FrameBaseModel):
             if len(prize_id_list) > 0:
                 prize_ids = ",".join(prize_id_list)
                 condition_where.add_condition("prize_id not in (" + prize_ids + ")")
-        prize_roster_model = PrizeRosterModel(context=self.context)
+        prize_roster_model = PrizeRosterModel(sub_table=self.get_business_sub_table("prize_roster_tb", {"act_id": act_id, "user_id": 0}),context=self.context)
         prize_roster_list = prize_roster_model.get_cache_dict_list(condition_where.to_string(), "", "create_date desc", str(page_size), "user_nick,prize_name,tag_id,module_name", params_list, cache_expire=60)
         total = int(len(prize_roster_list))
         if total == 0:
@@ -876,7 +885,7 @@ class OrderBaseModel(FrameBaseModel):
             false_act_prize_list = act_prize_model.get_cache_list(prize_condition, order_by="probability desc,chance desc", limit="30", params=prize_params,cache_expire=60)
             if len(false_act_prize_list) > 0 and add_num > 0:
                 now_datetime = TimeHelper.add_hours_by_format_time(hour=-random.randint(0, 1000))
-                user_info_list_dict = UserInfoModel(context=self.context).get_dict_list("act_id<%s and create_date>%s", params=[act_id,now_datetime], limit=str(add_num))
+                user_info_list_dict = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb", {"act_id": act_id, "user_id": 0}),context=self.context).get_dict_list("act_id<%s and create_date>%s", params=[act_id,now_datetime], limit=str(add_num))
 
                 for i in range(len(user_info_list_dict)):
                     false_act_prize = false_act_prize_list[random.randint(0, len(false_act_prize_list)-1)]
