@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 15:44:04
-@LastEditTime: 2022-01-13 15:04:46
+@LastEditTime: 2022-01-21 21:30:04
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -38,17 +38,17 @@ class ThemeBaseModel():
         cache_key = f"theme_info:themeid_{theme_id}_verno_{ver_no}"
         redis_init = SevenHelper.redis_init()
         if is_cache:
-             theme_info_dict = redis_init.get(cache_key)
-             if theme_info_dict:
-                    theme_info_dict = SevenHelper.json_loads(theme_info_dict)
-                    return theme_info_dict
-                    
+            theme_info_dict = redis_init.get(cache_key)
+            if theme_info_dict:
+                theme_info_dict = SevenHelper.json_loads(theme_info_dict)
+                return theme_info_dict
+
         theme_info_dict = theme_info_model.get_dict_by_id(theme_id)
         if not theme_info_dict:
             return theme_info_dict
         out_id = theme_info_dict["out_id"]
         if ver_no:
-            theme_ver = ThemeVerModel(context=self.context).get_dict("out_id=%s and ver_no=%s", params=[out_id, ver_no])
+            theme_ver = ThemeVerModel(context=self.context).get_dict("out_id=%s and ver_no=%s", limit="1", params=[out_id, ver_no])
             if theme_ver and theme_ver["client_json"] != "":
                 theme_info_dict["client_json"] = theme_ver["client_json"]
         skin_info_list = SkinInfoModel(context=self.context).get_dict_list("theme_id=%s", params=theme_id)
@@ -56,7 +56,7 @@ class ThemeBaseModel():
         if is_cache:
             redis_init.set(cache_key, SevenHelper.json_dumps(theme_info_dict), ex=config.get_value("cache_expire", 600))
         return theme_info_dict
-    
+
     def get_theme_list(self,app_id,is_public=True,is_cache=True):
         """
         :description: 获取主题列表
@@ -77,11 +77,11 @@ class ThemeBaseModel():
             dict_list = theme_info_model.get_cache_dict_list(where=where, params=params)
         else:
             dict_list = theme_info_model.get_dict_list(where=where, params=params)
-        
+
         for dict_info in dict_list:
             dict_info["server_json"] = SevenHelper.json_loads(dict_info["server_json"]) if dict_info["server_json"] else {}
         return dict_list
-    
+
     def get_skin_list(self, theme_id=0, theme_out_id="",is_cache=True):
         """
         :description: 获取皮肤列表
@@ -111,7 +111,7 @@ class ThemeBaseModel():
             dict_info["client_json"] = SevenHelper.json_loads(dict_info["client_json"]) if dict_info["client_json"] else {}
             dict_info["server_json"] = SevenHelper.json_loads(dict_info["server_json"]) if dict_info["server_json"] else {}
         return dict_list
-    
+
     def update_act_theme_and_skin(self,app_id,act_id,theme_id,is_module):
         """
         :description: 更新活动主题和皮肤
@@ -147,7 +147,7 @@ class ThemeBaseModel():
         if is_module == True:
             ActModuleModel(context=self.context).update_table("skin_id=%s", "act_id=%s", [skin_info.id, act_id])
         return invoke_result_data
-        
+
     def save_theme(self, app_id, theme_name, client_json, server_json, out_id, ver_no, style_type):
         """
         :description: 添加或修改主题
@@ -218,7 +218,7 @@ class ThemeBaseModel():
 
         return invoke_result_data
 
-    def save_skin(self, app_id, skin_name, client_json, server_json, theme_out_id, skin_out_id):
+    def save_skin(self, app_id, skin_name, client_json, server_json, theme_out_id, skin_out_id, style_type=0):
         """
         :description: 保存皮肤
         :param app_id：应用标识
@@ -227,6 +227,7 @@ class ThemeBaseModel():
         :param server_json：服务端内容json
         :param theme_out_id：样式外部id
         :param skin_out_id：皮肤外部id
+        :param style_type：样式类型
         :return: 
         :last_editors: HuangJianYi
         """
@@ -261,6 +262,7 @@ class ThemeBaseModel():
             skin_info.skin_name = skin_name
             skin_info.client_json = client_json
             skin_info.server_json = server_json
+            skin_info.style_type = style_type
             if app_id != "":
                 skin_info.app_id = app_id
             skin_info.sort_index = skin_info_total + 1
