@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-08-12 09:06:24
-@LastEditTime: 2022-02-23 17:33:57
+@LastEditTime: 2022-03-09 09:17:57
 @LastEditors: HuangJianYi
 :description: 淘宝top接口基础类
 """
@@ -21,7 +21,7 @@ class TopBaseModel():
         self.logging_link_error = logging_error
         self.logging_link_info = logging_info
 
-    def instantiate(self,app_id,user_nick,access_token,app_key, app_secret,is_log=False):
+    def instantiate(self, app_id, user_nick, access_token, app_key, app_secret, is_log=False):
         """
         :description: 实例化
         :param app_id:应用标识
@@ -34,14 +34,12 @@ class TopBaseModel():
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-
         base_info = BaseInfoModel(context=self.context).get_entity()
         if not base_info:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "基础信息未配置"
             return invoke_result_data
-
         app_name = base_info.product_name
         description = base_info.product_desc
         icon = base_info.product_icon
@@ -49,6 +47,7 @@ class TopBaseModel():
         template_version = base_info.client_ver
         app_info_model = AppInfoModel(context=self.context)
         app_info = None
+        is_change_project_code = False #是否改变了项目代码，用于判断是否进行了服务市场套餐的改变,第一次实例化默认False
 
         # 产品千牛后台GM工具（运营人员模拟登录）
         if app_id:
@@ -78,14 +77,19 @@ class TopBaseModel():
         if invoke_result_data.success == False:
             return invoke_result_data
         dead_date = invoke_result_data.data
+        project_code = self.get_project_code(store_user_nick,access_token, app_key, app_secret, is_log)
         if app_info:
             if dead_date != "expire":
                 app_info.expiration_date = dead_date
+            if project_code != "":
+                if project_code != app_info.project_code:
+                    is_change_project_code = True
+                app_info.project_code = project_code
             invoke_result_data = self.get_goods_list(0, 1, "", "", "", access_token, app_key, app_secret)
             if invoke_result_data.success == True:
                 app_info.access_token = access_token
-            app_info_model.update_entity(app_info, "expiration_date,access_token")
-            invoke_result_data.data = {"app_id": app_info.app_id, "store_user_nick": app_info.store_user_nick, "user_nick": user_nick, "access_token": app_info.access_token}
+            app_info_model.update_entity(app_info, "expiration_date,project_code,access_token")
+            invoke_result_data.data = {"app_id": app_info.app_id, "store_user_nick": app_info.store_user_nick, "user_nick": user_nick, "access_token": app_info.access_token,"is_change_project_code":is_change_project_code}
             return invoke_result_data
 
         # if ":" in user_nick:
@@ -136,6 +140,7 @@ class TopBaseModel():
             app_info.template_ver = req.template_version
             app_info.access_token = access_token
             app_info.expiration_date = dead_date
+            app_info.project_code = project_code
 
             if "shop_seller_get_response" in shop_info.keys():
                 app_info.store_name = shop_info["shop_seller_get_response"]["shop"]["title"]
@@ -161,7 +166,7 @@ class TopBaseModel():
             if "miniapp_template_onlineapp_response" in online_app_info.keys():
                 app_info.app_url = online_app_info["miniapp_template_onlineapp_response"]["app_info"]["online_url"]
             app_info.id = app_info_model.add_entity(app_info)
-            invoke_result_data.data = {"app_id": app_info.app_id, "store_user_nick": store_user_nick, "user_nick": user_nick, "access_token": access_token}
+            invoke_result_data.data = {"app_id": app_info.app_id, "store_user_nick": store_user_nick, "user_nick": user_nick, "access_token": access_token,"is_change_project_code":is_change_project_code}
             return invoke_result_data
         except Exception as ex:
             if self.context:
