@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2022-02-25 14:27:39
+@LastEditTime: 2022-04-29 15:13:24
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -52,7 +52,7 @@ class UserBaseModel(FrameBaseModel):
         """
         return f"user_black:{act_id}_{user_id}"
 
-    def _delete_user_black_cache(self, act_id, user_id, delay_delete_time=0.1):
+    def _delete_user_black_cache(self, act_id, user_id, delay_delete_time=0.01):
         """
         :description: 删除用户黑名单缓存
         :param act_id：活动标识
@@ -77,7 +77,7 @@ class UserBaseModel(FrameBaseModel):
         else:
             return f"user_info:actid_{act_id}_openid_{open_id}"
 
-    def _delete_user_info_cache(self, act_id, id_md5, delay_delete_time=0.1):
+    def _delete_user_info_cache(self, act_id, id_md5, delay_delete_time=0.01):
         """
         :description: 删除用户信息缓存
         :param act_id：活动标识
@@ -86,7 +86,7 @@ class UserBaseModel(FrameBaseModel):
         :return: 
         :last_editors: HuangJianYi
         """
-        UserInfoModel().delete_dependency_key(self.get_user_info_dependency_key(act_id, id_md5),delay_delete_time)
+        UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb", {"act_id": act_id, "user_id": 0})).delete_dependency_key(self.get_user_info_dependency_key(act_id, id_md5),delay_delete_time)
 
     def get_user_info_dict(self, app_id, act_id, user_id, open_id="", is_cache=True):
         """
@@ -101,7 +101,7 @@ class UserBaseModel(FrameBaseModel):
         user_info_dict = None
         if not act_id or (not user_id and not open_id):
             return user_info_dict
-        user_info_model = UserInfoModel(context=self.context)
+        user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb", {"act_id": act_id, "user_id": 0}),context=self.context)
         id_md5 = self._get_user_info_id_md5(act_id, user_id)
         dependency_key = self.get_user_info_dependency_key(act_id, id_md5, open_id)
         if id_md5:
@@ -162,7 +162,7 @@ class UserBaseModel(FrameBaseModel):
         if end_date:
             condition += " AND create_date<=%s"
             params.append(end_date)
-        page_list, total = UserInfoModel(context=self.context).get_dict_page_list("*", page_index, page_size, condition, order_by=order_by, params=params)
+        page_list, total = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb", {"act_id": act_id, "user_id": 0}),context=self.context).get_dict_page_list("*", page_index, page_size, condition, order_by=order_by, params=params)
         page_info = PageInfo(page_index, page_size, total, page_list)
         return page_info
 
@@ -208,7 +208,7 @@ class UserBaseModel(FrameBaseModel):
 
         user_account_model = UserAccountModel(context=self.context)
         user_info = None
-        user_info_model = UserInfoModel(context=self.context)
+        user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb", {"act_id": act_id, "user_id": 0}),context=self.context)
         now_datetime = SevenHelper.get_now_datetime()
         try:
             user_account = user_account_model.get_entity("open_id=%s", params=[open_id])
@@ -302,7 +302,7 @@ class UserBaseModel(FrameBaseModel):
 
         user_account_model = UserAccountModel(context=self.context)
         user_info_dict = None
-        user_info_model = UserInfoModel(context=self.context)
+        user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb", {"act_id": act_id, "user_id": 0}),context=self.context)
 
         try:
             user_info_dict = self.get_user_info_dict(app_id, act_id, user_id, open_id)
@@ -363,7 +363,7 @@ class UserBaseModel(FrameBaseModel):
         """
         invoke_result_data = InvokeResultData()
         id_md5 = self._get_user_info_id_md5(act_id, user_id)
-        user_info_model = UserInfoModel(context=self.context)
+        user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb", {"act_id": act_id, "user_id": 0}),context=self.context)
         user_info = user_info_model.get_entity("id_md5=%s", params=[id_md5])
         if not user_info:
             invoke_result_data.success = False
@@ -403,7 +403,7 @@ class UserBaseModel(FrameBaseModel):
         """
         invoke_result_data = InvokeResultData()
         db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
-        user_info_model = UserInfoModel(db_transaction=db_transaction, context=self.context)
+        user_info_model = UserInfoModel(db_transaction=db_transaction,sub_table=self.get_business_sub_table("user_info_tb", {"act_id": act_id, "user_id": 0}), context=self.context)
         user_black_model = UserBlackModel(db_transaction=db_transaction, context=self.context)
 
         user_info_dict = self.get_user_info_dict(app_id, act_id, user_id)
@@ -552,7 +552,7 @@ class UserBaseModel(FrameBaseModel):
             invoke_result_data.error_message = "非法操作"
             return invoke_result_data
 
-        user_info_model = UserInfoModel(context=self.context)
+        user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb", {"act_id": user_black.act_id, "user_id": 0}),context=self.context)
         id_md5 = self._get_user_info_id_md5(user_black.act_id, user_black.user_id)
         user_info = user_info_model.get_entity("id_md5=%s", params=[id_md5])
         if not user_info:
@@ -717,7 +717,7 @@ class UserBaseModel(FrameBaseModel):
                 #超过变成黑用户
                 if len(refund_order_data) >= refund_count:
                     result = True
-                    user_info_model = UserInfoModel(context=self.context)
+                    user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb", {"act_id": user_info_dict["act_id"], "user_id": 0}),context=self.context)
                     user_info_model.update_table("user_state=1", "id=%s", user_info_dict["id"])
                     user_black_model = UserBlackModel(context=self.context)
                     user_black = user_black_model.get_entity("act_id=%s and user_id=%s", params=[user_info_dict["act_id"], user_info_dict["user_id"]])
@@ -788,7 +788,6 @@ class UserBaseModel(FrameBaseModel):
         :param act_id：活动标识
         :param user_id：用户标识
         :param open_id：open_id
-        :param open_id：open_id
         :param user_address_id:用户地址标识
         :param real_name：真实姓名
         :param telephone：手机号码
